"use client";

import { Icon } from "@iconify/react/dist/iconify.js";
import { WavesIcon as Wave } from "lucide-react";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import type { PricingData, PricingFeature } from "@/utils/get-fake-data";

interface PricingCardsProps extends PricingData {
	locale: Locale;
}

export default function PricingCards({
	headerTitle,
	headerDescription,
	packages,
	locale,
}: PricingCardsProps) {
	const isRTL = locale === "ar";

	const renderFeatures = (features: PricingFeature[], isPopular?: boolean) => {
		return features?.map((feature) => (
			<li key={feature.id} className="flex items-start gap-2">
				<span className="mt-1.5 text-xs">
					<Icon
						icon="teenyicons:left-solid"
						width="15"
						height="15"
						className={cn(
							"text-custom-primary-accent",
							isPopular ? "text-white" : ""
						)}
					/>
				</span>
				<span
					className={cn(
						"text-base leading-6",
						isPopular ? "text-white" : "text-[#01161B]"
					)}
				>
					{feature.text?.[locale]}
				</span>
			</li>
		));
	};

	return (
		<section
			className={cn(
				"overflow-hidden bg-white px-4 py-16",
				isRTL ? "lg:pr-12" : "lg:pl-12"
			)}
		>
			<div className="container mx-auto">
				{/* Header */}
				<div
					className={cn(
						"mb-12 flex flex-col items-center justify-center gap-4 text-center"
					)}
				>
					<div className="flex items-center gap-2">
						<Wave className="h-6 w-6 text-custom-primary-accent" />
						<p className="text-base text-custom-primary-accent">
							{locale === "ar" ? "شركة بن طالب" : "Ben Talab"}
						</p>
					</div>
					<h2 className="text-5xl text-[#606676]">{headerTitle?.[locale]}</h2>
					<p className="max-w-2xl text-lg text-[#616161]">
						{headerDescription?.[locale]}
					</p>
				</div>

				{/* Pricing Cards */}
				<div className="grid gap-6 md:grid-cols-2 lg:grid-cols-3">
					{packages?.map((pkg) => (
						<div
							key={pkg.id}
							className={cn(
								"relative rounded-lg p-6",
								pkg.isPopular
									? "bg-[#2895C8] text-white"
									: "bg-[#FFFFFF] text-gray-900"
							)}
							style={{
								boxShadow: "0px 5px 40px 0px #67715F1A",
							}}
						>
							{pkg.isPopular && (
								<div
									className={cn(
										"absolute -top-3 right-6 rounded-md bg-gray-600 px-4 py-1 text-sm text-white",
										isRTL ? "left-6 right-auto" : "left-auto right-6"
									)}
								>
									{locale === "ar" ? "الأكثر طلباً" : "Most Popular"}
								</div>
							)}

							<div
								className={cn(
									"mb-8 flex flex-col items-center gap-1 rounded-md bg-[#0F9CB91A] p-6",
									pkg.isPopular && "bg-[#FFFFFF33]"
								)}
							>
								<h3
									className={cn(
										"text-2xl text-custom-primary-accent",
										pkg.isPopular && "text-white"
									)}
								>
									{pkg.name?.[locale]}
								</h3>
								<div className="mb-2 flex items-center gap-2">
									<span
										className={cn(
											"text-6xl font-bold",
											pkg.isPopular ? "text-white" : "text-[#606676]"
										)}
									>
										{pkg.price}
									</span>
									<span
										className={cn(
											"text-sm",
											pkg.isPopular ? "text-white" : "text-[#616161]"
										)}
									>
										{" "}
										{locale === "ar" ? "ريال سعودي" : "SAR"}
									</span>
								</div>
								<p
									className={cn(
										"text-base",
										pkg.isPopular ? "text-white" : "text-[#616161]"
									)}
								>
									{pkg.subtitle?.[locale]}
								</p>
							</div>

							<div className="mb-8">
								<p
									className={cn(
										"mb-4 text-sm",
										pkg.isPopular ? "text-white" : "text-blue-500"
									)}
								>
									{locale === "ar" ? "التفاصيل" : "Details"}
								</p>
								<ul className="space-y-4">
									{renderFeatures(pkg.features, pkg.isPopular ?? false)}
								</ul>
							</div>

							<button
								className={cn(
									"w-full rounded-[50px] px-8 py-4 text-base text-custom-primary-accent",
									pkg.isPopular ? "bg-white" : ""
								)}
								style={{
									border: pkg.isPopular
										? "1px solid #757575"
										: "1px solid #0F9CB9",
								}}
							>
								{pkg.buttonText?.[locale]}
							</button>
						</div>
					))}
				</div>
			</div>
		</section>
	);
}
